@@ -213,6 +213,10 @@ class ObjectDetectionWindow(QMainWindow):
 
             if os.path.exists(dat_name):
                 self.temp_path = os.path.join(os.getcwd(), 'temp')
+
+                if not os.path.exists(self.temp_path):
+                    os.makedirs(self.temp_path)
+
                 save_name = os.path.join(self.temp_path, os.path.basename(fileName))
                 add_grid(fileName, save_name, dat_file_name=dat_name)
                 image = QImage(save_name)
