@@ -1,7 +1,7 @@
 from cnn_runner.yolo.detect_yolo import YoloDetector
 from cnn_runner.yolor.detect_yolor import YoloRDetector
-from mm_detector import run_mm_detection
-import mask_r_cnn.aes_visual_detect as mask_detector
+from cnn_runner.mm_detector import run_mm_detection
+import cnn_runner.mask_r_cnn.aes_visual_detect as mask_detector
 
 from PyQt5 import QtCore
 import os
